@@ -1,7 +1,7 @@
 """devops with emojis"""
 
 import typer
-from typing import Optional
+from typing import Optional, Annotated
 
 import machineconfig.scripts.python.devops_helpers.cli_repos as cli_repos
 import machineconfig.scripts.python.devops_helpers.cli_config as cli_config
@@ -10,15 +10,17 @@ import machineconfig.scripts.python.devops_helpers.cli_data as cli_data
 import machineconfig.scripts.python.devops_helpers.cli_nw as cli_network
 
 
-def get_app():
-    app = typer.Typer(help="🛠️ DevOps operations", no_args_is_help=True, add_completion=True)
-    def install(which: Optional[str] = typer.Argument(None, help="Comma-separated list of program names to install, or group name if --group flag is set."),
-        group: bool = typer.Option(False, "--group", "-g", help="Treat 'which' as a group name. A group is bundle of apps."),
-        interactive: bool = typer.Option(False, "--interactive", "-ia", help="Interactive selection of programs to install."),
+def install(which: Annotated[Optional[str], typer.Argument(..., help="Comma-separated list of program names to install, or group name if --group flag is set.")],
+        group: Annotated[bool, typer.Option(..., "--group", "-g", help="Treat 'which' as a group name. A group is bundle of apps.")] = False,
+        interactive: Annotated[bool, typer.Option(..., "--interactive", "-ia", help="Interactive selection of programs to install.")] = False,
     ) -> None:
         """📦 Install essential packages"""
         import machineconfig.utils.installer_utils.installer as installer_entry_point
         installer_entry_point.main(which=which, group=group, interactive=interactive)
+
+
+def get_app():
+    app = typer.Typer(help="🛠️ DevOps operations", no_args_is_help=True, add_completion=True)
     _ = install
     app.command("install", no_args_is_help=True, help="🛠️ [i] Install essential packages")(install)
     app.command("i", no_args_is_help=True, help="Install essential packages", hidden=True)(install)
