@@ -16,12 +16,12 @@ add_to_path_if_not_already \
     "$HOME/.cargo/bin" \
     "$CONFIG_ROOT/scripts/linux" \
     "$HOME/dotfiles/scripts/linux" \
-    "$HOME/.nix-profile/bin" \
-    "/home/linuxbrew/.linuxbrew/bin" \
+
     "/usr/games"
 # this way, if the script was run multiple times, e.g. due to nested shells in zellij, there will be no duplicates in the path
 # export DISPLAY=localhost:0.0  # xming server
-
+    # "$HOME/.nix-profile/bin" \
+    # "/home/linuxbrew/.linuxbrew/bin" \
 
 # echo "Sourcing scripts ..."
 . $CONFIG_ROOT/settings/broot/br.sh
